@@ -23,16 +23,16 @@
 
 #include "assetjob.h"
 #include "assetoperations.h"
-#include "ballotaddassetjob.h"
-#include "ballotlistassetsjob.h"
-#include "ballotremoveassetjob.h"
+#include "collectionaddassetjob.h"
+#include "collectionlistassetsjob.h"
+#include "collectionremoveassetjob.h"
 #include "channelsjob.h"
 #include "changelanguagejob.h"
-#include "createballotjob.h"
-#include "deleteballotjob.h"
+#include "createcollectionjob.h"
+#include "deletecollectionjob.h"
 #include "installjob.h"
 #include "installjobsmodel.h"
-#include "listballotsjob.h"
+#include "listcollectionsjob.h"
 #include "participantinfojob.h"
 #include "registerjob.h"
 #include "signonjob.h"
@@ -54,7 +54,7 @@ Session::Private::Private(Session *parent)
 
 void Session::Private::setPoints(int p)
 {
-    if (p > -1) {
+    if (p > -1 && p != points) {
         points = p;
         emit q->pointsChanged(points);
     }
@@ -69,23 +69,20 @@ void Session::Private::jobFinished(NetworkJob *job)
 {
     job->deleteLater();
 
-    if (!job->isJsonResponse()) {
+    if (!job->isJsonResponse() || job->failed()) {
         return;
     }
 
-    if (authenticated && !job->authSuccess()) {
-        setPoints(0);
-        emit q->disconnected();
-    }
+    setPoints(job->points());
 
     if (authenticated != job->authSuccess()) {
-        authenticated = !authenticated;
+        authenticated = job->authSuccess();
+        if (!authenticated) {
+            emit q->disconnected();
+        }
         emit q->authenticated(authenticated);
     }
 
-    if (job->authSuccess()) {
-        setPoints(job->points());
-    }
 }
 
 QNetworkReply *Session::Private::get(const QUrl &url)
@@ -135,7 +132,7 @@ SignOnJob *Session::signOn()
     url.setEncodedPath(d->jsonPath("/auth"));
     url.addQueryItem(QLatin1String("auth_user"), d->userName);
     url.addQueryItem(QLatin1String("auth_password"), d->password);
-    url.addQueryItem(QLatin1String("auth_device"), d->deviceId);
+    url.addQueryItem(QLatin1String("auth_device"), d->storeId);
 
     //qDebug()<<"url is " <<url;
 
@@ -180,16 +177,16 @@ void Session::setPassword(const QString &password)
     }
 }
 
-QString Session::deviceId() const
+QString Session::storeId() const
 {
-    return d->deviceId;
+    return d->storeId;
 }
 
-void Bodega::Session::setDeviceId(const QString &device)
+void Bodega::Session::setStoreId(const QString &id)
 {
-    if (d->deviceId != device) {
-        d->deviceId = device;
-        emit deviceChanged();
+    if (d->storeId != id) {
+        d->storeId = id;
+        emit storeIdChanged();
     }
 }
 
@@ -326,9 +323,15 @@ QMap<ImageUrl, QUrl> Session::urlsForImage(const QString &name) const
     QMap<ImageUrl, QUrl> ret;
     for (itr = d->imageUrls.constBegin(); itr != d->imageUrls.constEnd();
          ++itr) {
-        QString path = QString::fromLatin1("%1/%2")
-                       .arg(itr.value().toString())
-                       .arg(name);
+        if (itr.key() == ImagePreviews) {
+            // we don't care about the previews images, as there may be
+            // multiple of them; they are fetched via AssetJob's previews()
+            continue;
+        }
+
+        const QString path = QString::fromLatin1("%1/%2")
+                             .arg(itr.value().toString())
+                             .arg(name);
 
         ret.insert(itr.key(), QUrl(path));
     }
@@ -441,8 +444,18 @@ Bodega::NetworkJob *Session::paymentMethod()
     QUrl url = d->baseUrl;
     const QString path = QString::fromLatin1("/participant/paymentMethod");
     url.setEncodedPath(d->jsonPath(path));
+    //qDebug()<<"url is " <<url;
 
+    NetworkJob *job = new NetworkJob(d->get(url), this);
+    d->jobConnect(job);
+    return job;
+}
 
+Bodega::NetworkJob *Session::deletePaymentMethod()
+{
+    QUrl url = d->baseUrl;
+    const QString path = QString::fromLatin1("/participant/deletePaymentMethod");
+    url.setEncodedPath(d->jsonPath(path));
     //qDebug()<<"url is " <<url;
 
     NetworkJob *job = new NetworkJob(d->get(url), this);
@@ -581,24 +594,23 @@ Bodega::NetworkJob *Session::changeAccountDetails(const QString &firstName, cons
     return job;
 }
 
-Bodega::ListBallotsJob *Session::listBallots(int offset, int pageSize)
+Bodega::ListCollectionsJob *Session::listcollections(int offset, int pageSize)
 {
     QUrl url = d->baseUrl;
-    const QString path = QString::fromLatin1("/collections/list");
-
+    const QString path = QString::fromLatin1("/collection/list");
 
     url.setEncodedPath(d->jsonPath(path));
     d->addPaging(url, offset, pageSize);
 
     //qDebug()<<"url is " <<url;
 
-    ListBallotsJob *job = new ListBallotsJob(d->get(url), this);
+    ListCollectionsJob *job = new ListCollectionsJob(d->get(url), this);
     d->jobConnect(job);
     return job;
 }
 
-Bodega::CreateBallotJob * Session::createCollection(const QString &name,
-                                                BallotInfo::BallotFlags flags)
+Bodega::CreatecollectionJob * Session::createCollection(const QString &name,
+                                                CollectionInfo::CollectionFlags flags)
 {
     QUrl url = d->baseUrl;
     const QString path = QString::fromLatin1("/collections/create");
@@ -606,12 +618,12 @@ Bodega::CreateBallotJob * Session::createCollection(const QString &name,
     url.setEncodedPath(d->jsonPath(path));
 
     url.addQueryItem(QLatin1String("name"), name);
-    if (flags.testFlag(BallotInfo::Public)) {
+    if (flags.testFlag(CollectionInfo::Public)) {
         url.addQueryItem(QLatin1String("public"), QLatin1String("true"));
     } else {
         url.addQueryItem(QLatin1String("public"), QLatin1String("false"));
     }
-    if (flags.testFlag(BallotInfo::Wishlist)) {
+    if (flags.testFlag(CollectionInfo::Wishlist)) {
         url.addQueryItem(QLatin1String("wishlist"), QLatin1String("true"));
     } else {
         url.addQueryItem(QLatin1String("wishlist"), QLatin1String("false"));
@@ -619,12 +631,12 @@ Bodega::CreateBallotJob * Session::createCollection(const QString &name,
 
     //qDebug()<<"url is " <<url;
 
-    CreateBallotJob *job = new CreateBallotJob(d->get(url), this);
+    CreatecollectionJob *job = new CreatecollectionJob(d->get(url), this);
     d->jobConnect(job);
     return job;
 }
 
-Bodega::DeleteBallotJob * Session::deleteCollection(const QString &collectionId)
+Bodega::DeletecollectionJob * Session::deleteCollection(const QString &collectionId)
 {
     QUrl url = d->baseUrl;
     const QString path = QString::fromLatin1("/collections/delete");
@@ -635,12 +647,12 @@ Bodega::DeleteBallotJob * Session::deleteCollection(const QString &collectionId)
 
     //qDebug()<<"url is " <<url;
 
-    DeleteBallotJob *job = new DeleteBallotJob(d->get(url), this);
+    DeletecollectionJob *job = new DeletecollectionJob(d->get(url), this);
     d->jobConnect(job);
     return job;
 }
 
-Bodega::BallotAddAssetJob * Session::collectionAddAsset(const QString &collectionId,
+Bodega::collectionAddAssetJob * Session::collectionAddAsset(const QString &collectionId,
                                                     const QString &assetId)
 {
     QUrl url = d->baseUrl;
@@ -653,12 +665,12 @@ Bodega::BallotAddAssetJob * Session::collectionAddAsset(const QString &collectio
 
     //qDebug()<<"url is " <<url;
 
-    BallotAddAssetJob *job = new BallotAddAssetJob(d->get(url), this);
+    collectionAddAssetJob *job = new collectionAddAssetJob(d->get(url), this);
     d->jobConnect(job);
     return job;
 }
 
-Bodega::BallotRemoveAssetJob * Session::collectionRemoveAsset(const QString &collectionId,
+Bodega::collectionRemoveAssetJob * Session::collectionRemoveAsset(const QString &collectionId,
                                                           const QString &assetId)
 {
     QUrl url = d->baseUrl;
@@ -671,24 +683,23 @@ Bodega::BallotRemoveAssetJob * Session::collectionRemoveAsset(const QString &col
 
     //qDebug()<<"url is " <<url;
 
-    BallotRemoveAssetJob *job = new BallotRemoveAssetJob(d->get(url), this);
+    collectionRemoveAssetJob *job = new collectionRemoveAssetJob(d->get(url), this);
     d->jobConnect(job);
     return job;
 }
 
-Bodega::BallotListAssetsJob * Session::collectionListAssets(const QString &collectionId,
+Bodega::collectionListAssetsJob * Session::collectionListAssets(const QString &collectionId,
                                                         int offset,
                                                         int pageSize)
 {
     QUrl url = d->baseUrl;
-    const QString path = QString::fromLatin1("/collections/listAssets");
-
-    url.setEncodedPath(d->jsonPath(path));
+    const QString path = QString::fromLatin1("/collection/list/");
+    url.setEncodedPath(d->jsonPath(path + collectionId));
     d->addPaging(url, offset, pageSize);
 
     //qDebug()<<"url is " <<url;
 
-    BallotListAssetsJob *job = new BallotListAssetsJob(d->get(url), this);
+    collectionListAssetsJob *job = new collectionListAssetsJob(d->get(url), this);
     d->jobConnect(job);
     return job;
 }
